%define oname	Eterm

%define major	%{version}
%define libname	%mklibname %{name} %{major}
%define devname	%mklibname %{name} -d

Summary:	Terminal emulator
Name:		eterm
Version:	0.9.7
Release:	%mkrel 9
License:	BSD
Group:		Terminals
URL:		https://git.enlightenment.org/apps/eterm.git
Source0:	%{oname}-%{version}.tar.gz
Source5:	http://www.eterm.org/download/%{oname}-bg-0.9.6.tar.gz
Patch0:		CVE-2021-33477.patch
#  with Fix for graphics/imlib2 update 
# imlib_strerror() has been introduced to imlib2; mangle local version.
# from http://cvsweb.netbsd.org/bsdweb.cgi/pkgsrc/x11/eterm/patches/patch-src_pixmap.c
Patch1:		patch-src_pixmap.c
Patch2:		patch-src_pixmap.h
Patch3:		eterm-0.9.6-gcc10.patch
Patch4:		eterm-0.9.6-gcc14.patch
Patch5:		eterm-c99-headers.patch
BuildRequires:	pkgconfig(imlib2)
BuildRequires:	libast-devel >= 0.5
BuildRequires:	utempter-devel
BuildRequires:	pkgconfig(x11)
BuildRequires:	twin-devel
BuildRequires:	pkgconfig(xres)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xmu)
BuildRequires:  groff-for-man
BuildRequires:	man
BuildRequires:	gdb
BuildRequires:	chrpath
Requires(pre):	ncurses
# needed by Etbg_update_list script
Requires(post):	diffutils
Provides:	%{oname} = %{version}-%{release}
Obsoletes:	%{oname} < %{version}-%{release}

%description
Eterm is a color vt102 terminal emulator intended as a replacement for Xterm.
It is designed with a Freedom of Choice philosophy, leaving as much power,
flexibility, and freedom as possible in the hands of the user.

It is designed to look good and work well, but takes a feature-rich approach
rather than one of minimalism while still maintaining speed and efficiency.

It works on any windowmanager/desktop environment, although it is designed
to work and integrate best with Enlightenment.

%package -n	%{libname}
Summary:	Library from Eterm (Enlightened Terminal Emulator)
Group:		Terminals

%description -n	%{libname}
Eterm is a color vt102 terminal emulator intended as a replacement for Xterm.
It is designed with a Freedom of Choice philosophy, leaving as much power,
flexibility, and freedom as possible in the hands of the user.

It is designed to look good and work well, but takes a feature-rich approach
rather than one of minimalism while still maintaining speed and efficiency.

It works on any windowmanager/desktop environment, although it is designed
to work and integrate best with Enlightenment.

This library is essential for Eterm to work.

%package -n %{devname}
Summary:	Devel files for Eterm
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Obsoletes:	%{oname}-devel < %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{oname}-devel = %{version}-%{release}

%description -n %{devname}
Eterm is a color vt102 terminal emulator intended as a replacement for Xterm.
It is designed with a Freedom of Choice philosophy, leaving as much power,
flexibility, and freedom as possible in the hands of the user.

It is designed to look good and work well, but takes a feature-rich approach
rather than one of minimalism while still maintaining speed and efficiency.

It works on any windowmanager/desktop environment, although it is designed
to work and integrate best with Enlightenment.

This package provides the necessary development libraries and include files
to allow you to develop or compile programs that needs Eterm, though no such
program has existed so far.

%prep
%setup -q -a5 -n %{oname}-%{version}
%patch -P 0 -p1
%patch -P 1 -p0
%patch -P 2 -p0
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1

# fix rpmlint warning
# change character encoding
mv ChangeLog ChangeLog.old
iconv -f ISO-8859-1 -t UTF8 -o ChangeLog ChangeLog.old

# patch1 also sets $TERM = xterm for all themes,
# do that here since patch1 is not applied
find themes/ -name 'theme.cfg.in' -print0 | xargs -0 -r perl -pi -e 's/term_name Eterm/term_name xterm/'

%build
autoreconf -fi
# still to fix the good way
export CFLAGS="%{optflags} -std=gnu17"
%configure \
  --enable-etwin \
  --enable-escreen-fx \
  --enable-profile \
  --enable-trans \
  --with-backspace=bs \
  --disable-mmx \
  --enable-utmp \
  --with-delete=execute \
  --enable-auto-encoding \
  --enable-multi-charset \
  --enable-xim \
  --enable-greek \
  --disable-static

%make_build

%install
%make_install

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Eterm
Comment=Enlightened Terminal Emulator
Exec=%{oname}
Icon=terminals_section
Terminal=false
Type=Application
Categories=System;TerminalEmulator;
EOF

#for %%ghost file
touch %{buildroot}%{_datadir}/%{oname}/pix/pixmaps.list.old

# fiw rpmlint warning
# remove rpath
chrpath -d %{buildroot}%{_bindir}/{Esetroot,Eterm}

#we don't want these
rm -rf %{buildroot}%{_libdir}/*.la

%post
%{_bindir}/Etbg_update_list %{_datadir}/%{oname}/pix/

%files
%defattr(-, root, root,0755)
%doc ChangeLog README ReleaseNotes doc/Eterm_reference.html doc/README.Escreen
%{_bindir}/*
%dir %{_datadir}/%{oname}
%{_datadir}/%{oname}/gdb.scr
%config(noreplace) %{_datadir}/%{oname}/themes
%dir %{_datadir}/%{oname}/pix
%ghost %{_datadir}/%{oname}/pix/pixmaps.list.old
%{_datadir}/%{oname}/pix/tile
%{_datadir}/%{oname}/pix/scale
%{_datadir}/%{oname}/pix/*.png
%{_datadir}/%{oname}/pix/pixmaps.list
%{_mandir}/man1/Eterm.1.*
%{_datadir}/applications/%{name}.desktop

%files -n %{libname}
%{_libdir}/lib%{oname}-%{major}.so

%files -n %{devname}
%{_libdir}/lib%{oname}.so


%changelog
* Mon Apr 28 2025 papoteur <papoteur> 0.9.7-9.mga10
+ Revision: 2179533
- workaround build with GCC 15

* Sat Oct 26 2024 eatdirt <eatdirt> 0.9.7-8.mga10
+ Revision: 2111342
- Disabling mmx and removing obsoleted obsoletes

* Tue Oct 01 2024 ns80 <ns80> 0.9.7-7.mga10
+ Revision: 2102281
- add patches from Fedora to fix building with GCC 14

* Fri Mar 03 2023 papoteur <papoteur> 0.9.7-6.mga9
+ Revision: 1946728
- fix build with new imlib2

* Thu Mar 31 2022 umeabot <umeabot> 0.9.7-5.mga9
+ Revision: 1836251
- Mageia 9 Mass Rebuild

* Thu Jul 08 2021 ns80 <ns80> 0.9.7-4.mga9
+ Revision: 1735161
- add Debian patch for CVE-2021-33477 (mga#28939)

* Thu Feb 13 2020 umeabot <umeabot> 0.9.7-3.mga8
+ Revision: 1512098
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 0.9.7-2.mga7
+ Revision: 1297626
- Mageia 7 Mass Rebuild
+ kekepower <kekepower>
- Use new make macros

* Tue Nov 29 2016 eatdirt <eatdirt> 0.9.7-1.mga6
+ Revision: 1070995
- Upgrade to version 0.9.7

* Tue Feb 02 2016 umeabot <umeabot> 0.9.6-10.mga6
+ Revision: 932831
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.9.6-9.mga5
+ Revision: 746886
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.6-8.mga5
+ Revision: 679035
- Mageia 5 Mass Rebuild

* Sat Sep 06 2014 luigiwalser <luigiwalser> 0.9.6-7.mga5
+ Revision: 672788
- rebuild for libutempter

* Sat Oct 19 2013 umeabot <umeabot> 0.9.6-6.mga4
+ Revision: 522492
- Mageia 4 Mass Rebuild

* Sun Mar 10 2013 rtp <rtp> 0.9.6-5.mga3
+ Revision: 402059
- enable mmx only on x86/x86_64 platforms

* Fri Jan 11 2013 umeabot <umeabot> 0.9.6-4.mga3
+ Revision: 349747
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Aug 29 2012 eatdirt <eatdirt> 0.9.6-3.mga3
+ Revision: 285403
- Remove conflicts with ncurses-extraterms

* Mon Nov 07 2011 wally <wally> 0.9.6-2.mga2
+ Revision: 164971
- fix post scriptlets (mga#3280)
- fix file list
- fix some rpmlint warnings
  * character encoding
  * rpath

* Tue Jun 14 2011 wally <wally> 0.9.6-1.mga2
+ Revision: 106156
- rename package to eterm
- new version 0.9.6
- fixes CVE-2011-0409
- fixes CVE-2011-0768
- fix libification
- disable static build

* Sun May 15 2011 pterjan <pterjan> 0.9.5-13.mga1
+ Revision: 98978
- Rebuild for fixed find-requires

* Mon Apr 25 2011 wally <wally> 0.9.5-12.mga1
+ Revision: 90254
- drop P1, unused since forever

* Mon Apr 25 2011 wally <wally> 0.9.5-11.mga1
+ Revision: 90241
- raise rel so package gets updated when updating from Mdv
- fix desktop file name (mga#954)
- fix desktop file
- unpack patch
- more .spec cleaning

* Tue Apr 19 2011 ennael <ennael> 0.9.5-1.mga1
+ Revision: 88286
- clean spec file
+ steletch <steletch>
- One spec typo was left
- More cleanup of the spec file
- Clean spec file
- imported package Eterm


* Wed Feb 02 2011 Funda Wang <fwang@mandriva.org> 0.9.5-12mdv2011.0
+ Revision: 634984
- rebuild
- tighten BR

* Sun Dec 05 2010 Oden Eriksson <oeriksson@mandriva.com> 0.9.5-11mdv2011.0
+ Revision: 610387
- rebuild

* Thu Mar 25 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.9.5-10mdv2010.1
+ Revision: 527511
- drop patch6 (fixes mdv bug#57971)

* Wed Dec 16 2009 Antoine Ginies <aginies@mandriva.com> 0.9.5-9mdv2010.1
+ Revision: 479244
+ rebuild (emptylog)

* Tue Sep 15 2009 Thierry Vignaud <tv@mandriva.org> 0.9.5-8mdv2010.0
+ Revision: 443019
- buildrequires X11-devel instead of libxt-devel
- build terminfo entries at build time and own it instead of building it at
  install time (cautgh by Andrey Borzenkov)
- conflicts with ncurses-extra because of this

* Mon Sep 14 2009 Thierry Vignaud <tv@mandriva.org> 0.9.5-7mdv2010.0
+ Revision: 439693
- fix post script (Charles A Edwards)

* Thu Sep 10 2009 Thierry Vignaud <tv@mandriva.org> 0.9.5-6mdv2010.0
+ Revision: 437484
- rebuild

* Wed Apr 01 2009 Antoine Ginies <aginies@mandriva.com> 0.9.5-5mdv2009.1
+ Revision: 363155
- add gdb buildrequires
- fix problem of devel librairies installed by default (new lib package)

* Tue Mar 03 2009 Antoine Ginies <aginies@mandriva.com> 0.9.5-4mdv2009.1
+ Revision: 348045
- add missing lib
- add freetype-devel and twin-devel buildrequires
- add some buildrequires
- add missing files (*.a *.la)
- add some doc files
- remove missing file
- new release, add utf8 support, remove some old patch

* Mon Mar 02 2009 Antoine Ginies <aginies@mandriva.com> 0.9.3-8mdv2009.1
+ Revision: 346976
- do not regenerate all configure files

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - rebuild
    - fix "foobar is blabla" summary (=> "blabla") so that it looks nice in rpmdrake
    - drop old menu
    - kill re-definition of %%buildroot on Pixel's request
    - import Eterm

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot


* Wed Sep 06 2006 Jerome Soyer <saispo@mandriva.org> 0.9.3-5mdv2007.0
- XDG Menu
- Fix alternatives error

* Wed Jun 07 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 0.9.3-4mdv2007.0
- fix buildrequires

* Fri May 12 2006 Couriousous <couriousous@mandriva.org> 0.9.3-3mdk
- Yearly rebuild
- Fix gcc4 build

* Thu Apr 28 2005 Couriousous <couriousous@mandriva.org> 0.9.3-2mdk
- From trem : 
    - Disable mmx ( fix amd64 compile and not all i586 have mmx )

* Thu Feb 03 2005 Abel Cheung <deaddog@mandrake.org> 0.9.3-1mdk
- New version
- Don't apply patch1, use Eterm-bg again since copyright is clear now
- All programs written by Rasterman has been GPL'ed. Yay!
- Can't bear with non-antialiased icons, better use mdk default ones
- P3: Don't link against freetype 1.x
- Add missing (Build)Requires
- mklibname
- Remove so-called devel package, which is useless
- Update Eterm background image list in scriptlet

* Tue Jun 01 2004 Michael Scherer <misc@mandrake.org> 0.9.2-6mdk 
- [DIRM]

* Sat May 15 2004 Michael Scherer <misc@mandrake.org> 0.9.2-5mdk 
- remove devel requrement

* Fri May 14 2004 Michael Scherer <misc@mandrake.org> 0.9.2-4mdk 
- Birthday rebuild
- rpmbuildupdate aware
- fix some rpmlint warning

* Sun Apr 20 2003 Stefan van der Eijk <stefan@eijk.nu> 0.9.2-3mdk
- BuildRequires

* Mon Jan 27 2003 Vincent Danen <vdanen@mandrakesoft.com> 0.9.2-2mdk
- Requires: libast1 >= 0.5

* Fri Jan 24 2003 Vincent Danen <vdanen@mandrakesoft.com> 0.9.2-1mdk
- 0.9.2
- rediff P2
- fix typeo in mutt theme
- build with Escreen support

* Wed Aug 28 2002 Ben Reser <ben@reser.org> 0.9.1-6mdk
- Remove menu entries for missing backgrounds and regenerate the patches

* Mon Aug 26 2002 David BAUDENS <baudens@mandrakesoft.com> 0.9.1-5mdk
- Remove Eterm-bg because there is no copyright note for theses images

* Sat Aug 24 2002 Ben Reser <ben@reser.org> 0.9.1-4mdk
- I knew I should have waited to put this out... 
- Fix colors in the mutt theme so they match mutt's color
  names. 
- Turn off scrollbar in mutt theme.
- While I'm at it modify all the themes to default to
  xterm
- Make /usr/share/Eterm/themes/* %%config(noreplace)

* Sat Aug 24 2002 Ben Reser <ben@reser.org> 0.9.1-3mdk
- Add --enable-multi-charset, makes Eterm like multi-byte wide fonts.
- Put the background images back in.
- Fix the menus so they point only to backgrounds that are included.
- Add some missing documentation files
- Ported and added the mutt and irc themes from Eterm 0.8.10

* Fri Aug 23 2002 Vincent Danen <vdanen@mandrakesoft.com> 0.9.1-2mdk
- BuildRequires: libast-devel, freetype-devel, imlib2-devel (not
  imlib-devel) (re: ben@reser.org)
- Requires: libimlib2_1-loaders (re: ben@reser.org)
- put icons back
- use --with-delete=execute, --with-backspace=bs, and --enable-trans
  in configure
- better cleanup
- put libEterm.la into -devel
- fix update alternatives so they actually point to Eterm
- add termcap and terminfo files to package
- have %%post create the terminfo file on the system


* Mon Aug 19 2002 David BAUDENS <baudens@mandrakesoft.com> 0.9.1-1mdk
- 0.9.1

* Wed Feb  6 2002 Stefan van der Eijk <stefan@eijk.nu> 0.8.10-20mdk
- BuildRequires

* Thu Jan 31 2002 Thierry Vignaud <tvignaud@mandrakesoft.com> 0.8.10-19mdk
- remvove RPM_SOURCE_DIR usage
- xpm -> png icons

* Wed Dec 19 2001 Yves Duret <yduret@mandrakesoft.com> 0.8.10-18mdk
- rebuild against libpng3 !! (dadou too lazy to do it).
- corrected version number to 0.8.10 instead of O.8.10 (yeah capital o)

* Mon Sep 17 2001 Christian Belisle <cbelisle@mandrakesoft.com> O.8.10-17mdk
- Fixed menu entry

* Mon Jul 23 2001 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> O.8.10-16mdk
- BuildRequires: s/utempter-devel/libutempter0-devel
- s/Copyright/License

* Tue Mar 27 2001 Thierry Vignaud <tvignaud@mandrakesoft.com> O.8.10-15mdk
- various dedadoufication (aka spec cleaning) :
- get rid of stupid tar
- simplify scripts
- use right macros
- %%install doesn't need to clean
- ...

* Thu Feb  8 2001 Warly <warly@mandrakesoft.com> O.8.10-14mdk
- add alternatives on xvt

* Sat Jan 27 2001 Vincent Danen <vdanen@mandrakesoft.com> O.8.10-13mdk
- Rebuild to fix problems with loading (Eterm kept crashing)

* Mon Nov 13 2000 David BAUDENS <baudens@mandrakesoft.com> O.8.10-12mdk
- Build with glibc-2.2 & gcc-2.96

* Fri Sep 25 2000 David BAUDENS <baudens@mandrakesoft.com> O.8.10-11mdk
- Fix keyboard section for Mutt theme (thanks to Ben Reser)

* Fri Sep 01 2000 David BAUDENS <baudens@mandrakesoft.com> O.8.10-10mdk
- Fix delete key problem (thanks to Anton Graham)
- Make RPMLint happy

* Mon Aug 07 2000 Frederic Lepied <flepied@mandrakesoft.com> O.8.10-9mdk
- automatically added BuildRequires

* Tue Apr 18 2000 Daouda Lo <daouda@mandrakesoft.com> 0.8.10-8mdk
- run update-menu in post and postun sections
- fix version 
- SMP build/check

* Wed Mar 29 2000 David BAUDENS <baudens@mandrakesoft.com> 0.16-7mdk
- Menu support
- Disable visual bell
- Fix a typo in Summary

* Mon Mar 27 2000 David BAUDENS <baudens@mandrakesoft.com> 0.10-6mdk
- Enable Mandrake Theme

* Mon Mar 27 2000 David BAUDENS <baudens@mandrakesoft.com> 0.10-5mdk
- Use new Group
- Use %%{_tmppath} for BuildRoot
- Update Description

* Mon Jan 03 2000 David BAUDENS <baudens@mandrakesoft.com>
- Fix name

* Sun Dec 26 1999 - David BAUDENS <baudens@mandrakesoft.com>
- Fix bg

* Sat Dec 25 1999 - David BAUDENS <baudens@mandrakesoft.com>
- Add utemper patch from Tim POWERS <tim@redhat.com>

* Tue Nov 25 1999 - David BAUDENS <baudens@mandrakesoft.com> 
- 0.8.10 
- Make relocatable
- Clean up spec file
  
* Wed Dec 30 1998 mej <mej@mw.3com.com> 
- Added spec file.  Created by techn0ir <technoir@themes.org> 
- Modified spec file for Mandrake <johnb@mandrakesoft.com> 
